#!/usr/bin/python

# This file is part of Window-Switch.
# Copyright (c) 2009-2011 Antoine Martin <antoine@nagafix.co.uk>
# Window-Switch is released under the terms of the GNU GPL v3

import sys
from winswitch.util.simple_logger import set_log_filename, set_log_dir, set_log_to_file, set_log_to_tty
from winswitch.util.paths import CLIENT_DIR, CLIENT_LOG

py2app=False
if sys.platform.startswith("darwin"):
	py2app = True
	#insert the site-packages.zip generated by py2app at the top of the path list
	sys.path.insert(0,'../Resources/lib/python%d.%d/site-packages.zip' % (sys.version_info[0], sys.version_info[1]))

def usage():
	print("Usage: %s" % sys.argv[0])
	print("")
	print("  -h   --help			Usage information")
	print("  -l   --log-to-file		Log messages to file")
	print("  --version				Print version information and exit")
	set_log_to_file(False)
	set_log_to_tty(False)
	from winswitch.objects.common import add_argv_usage
	from winswitch.objects.global_settings import GlobalSettings
	add_argv_usage(GlobalSettings())
	print("")

def stdout():
	set_log_to_file(False)
	set_log_to_tty(True)

def log_to_file():
	set_log_to_file(True)
	set_log_to_tty(False)
	

def main():
	set_log_dir(CLIENT_DIR)
	set_log_filename(CLIENT_LOG)
	args = sys.argv
	import winswitch.globals			#ensure it is imported from the top level class
	assert winswitch.globals.USERNAME	#ensures that the line above doesn't trigger a pydev warning
	stdout()
	if "-h" in args or "--help" in args:
		usage()
		return
	if "--version" in sys.argv:
		from winswitch.util.version_info import print_version_info
		print_version_info()
		return
	#if running via py2app bundle, probably no terminal, so log to file:
	global py2app
	if "-l" in args or "--log-to-file" in args or py2app:
		log_to_file()

	from winswitch.client.applet import main
	code = main(args)
	sys.exit(code)

if __name__ == "__main__":
	main()
